md_harmonize
============

.. image:: https://img.shields.io/pypi/v/md_harmonize.svg
   :target: https://pypi.org/project/md-harmonize/
   :alt: Current library version

.. image:: https://img.shields.io/pypi/pyversions/md_harmonize.svg
   :target: https://pypi.org/project/md-harmonize
   :alt: Supported Python versions


md_harmonize package provides facilities for creation and harmonization of compounds and reactions.

Citation
~~~~~~~~

Please cite the GitHub repository until our manuscript is accepted for
publication: https://github.com/MoseleyBioinformaticsLab/md_harmonize.git

Installation
~~~~~~~~~~~~

md_harmonize runs under Python 3.7+ and is available through python3-pip.
Install via pip or clone the git repo and install the following dependencies and
you are ready to go!

Install on Linux
~~~~~~~~~~~~~~~~

Pip installation
----------------
        
.. code:: bash

   python3 -m pip install md-harmonize

Note: 
   Please add ~/.local/bin/ to the environmental PATH variant in bash_profile if you install the package with --user.
   
   python3-devel  is required for package installation. 

GitHub Package installation
---------------------------

.. code:: bash

   git clone git@github.com:MoseleyBioinformaticsLab/md_harmonize.git

License
~~~~~~~

Made available under the terms of The modified Clear BSD License. See full license in LICENSE_.

Authors
~~~~~~~

* **Huan Jin**
* **Hunter N.B. Moseley**


.. _LICENSE: https://github.com/MoseleyBioinformaticsLab/MDH/blob/master/LICENSE

